#
# spec file for package python-gwpy
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Python2 no longer supported upstream
%define         skip_python2 1

Name:           python-gwpy
Version:        2.1.5
Release:        1.1
Summary:        A python package for gravitational-wave astrophysics
License:        GPL-3.0-only
URL:            https://gwpy.github.io/
Source:         https://files.pythonhosted.org/packages/source/g/gwpy/gwpy-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-astropy >= 3.0.0
Requires:       python-dqsegdb2
Requires:       python-gwosc
Requires:       python-h5py
Requires:       python-lal
Requires:       python-ligo-segments
Requires:       python-matplotlib >= 3.1.0
Requires:       python-numpy
Requires:       python-python-dateutil
Requires:       python-requests
Requires:       python-scipy
Requires:       python-tqdm
Recommends:     python-PyCBC
Recommends:     python-PyMySQL
Recommends:     python-lalsimulation
Recommends:     python-lscsoft-glue
BuildArch:      noarch
# SECTION test requirements
# BuildRequires:  %%{python_module PyCBC} -- optional, not available on aarch64
BuildRequires:  %{python_module PyMySQL}
BuildRequires:  %{python_module astropy >= 3.0.0}
BuildRequires:  %{python_module dqsegdb2}
BuildRequires:  %{python_module freezegun}
BuildRequires:  %{python_module framel}
BuildRequires:  %{python_module gwosc}
BuildRequires:  %{python_module h5py}
BuildRequires:  %{python_module lal}
BuildRequires:  %{python_module lalsimulation}
BuildRequires:  %{python_module ligo-segments}
BuildRequires:  %{python_module matplotlib >= 3.1.0}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest >= 3.3}
BuildRequires:  %{python_module requests-mock}
BuildRequires:  %{python_module scipy}
BuildRequires:  %{python_module tqdm}
# /SECTION
# Unsupported archs by upstream
ExcludeArch:    %ix86
Requires(post): update-alternatives
Requires(postun):update-alternatives
%python_subpackages

%description
GWpy is a collaboration-driven Python package providing tools for
studying data from ground-based gravitational-wave detectors.

GWpy provides a user-friendly, intuitive interface to the common
time-domain and frequency-domain data produced by the LIGO and Virgo
observatories and their analyses, with easy-to-follow tutorials at each
step.

%prep
%autosetup -p1 -n gwpy-%{version}
sed -Ei "1{/^#!\/usr\/bin\/env python/d}" gwpy/cli/*.py
sed -Ei "1{/^#!\/usr\/bin\/env python/d}" gwpy/utils/sphinx/*.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/gwpy-plot
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# deselecting tests:
# - examples are not installed into buildroot: test via pyargs
# - automatic skips by python-gwpy-connectionerror-test.patch
# - test_fetch_open_data in multiple modules try to connect to
#   gw-openscience.org
%{python_expand sed -i "s/python --blah/$python --blah/" gwpy/utils/tests/test_shell.py
sed -i "s/'python'/'$python'/g" gwpy/utils/tests/test_shell.py
}
%pytest --pyargs gwpy -k "not (fetch_open_data or test_timeseries or test_io_losc)"

%post
%python_install_alternative gwpy-plot
%postun
%python_uninstall_alternative gwpy-plot

%files %{python_files}
%license LICENSE
%doc README.md examples
%python_alternative %{_bindir}/gwpy-plot
%{python_sitelib}/gwpy/
%{python_sitelib}/gwpy-%{version}-py%{python_version}.egg-info/

%changelog
* Thu Sep  1 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.1.5:
  * [gh#gwpy/gwpy#1521] fix compatibility with scipy 1.9.0.
  * [gh#gwpy/gwpy#1523] deprecate the gwpy.utils.null_context
    function.
  * [gh#gwpy/gwpy#1530] fix some lint.
* Thu Jan 20 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.1.3:
  * [gh#gwpy/gwpy#1401] update test suite to use tmp_path fixture
    in pytest.
  * [gh#gwpy/gwpy#1418] add support for Python 3.10.
  * [gh#gwpy/gwpy#1439] fix DeprecationWarning emitted in Python
    3.10.
  * [gh#gwpy/gwpy#1438] update timeseries/public example.
  * [gh#gwpy/gwpy#1456] decorate test to skip gracefully on
    network error.
  * [gh#gwpy/gwpy#1457] fix compatibility with python-ligo-lw
    1.8.0.
  * [gh#gwpy/gwpy#1458] fix compatibility with scipy 1.8.0.
- Drop skip_python36 macro: python3.6 is now out of Factory
  anyway.
- Drop python-gwpy-connectionerror-test.patch: No longer required.
- Drop python-gwpy-python3-shell-test.patch: Use sed to substitute
  flavour specific python executable for 'python'.
- Use update-alternatives to install binary; Add Requires(post):
  update-alternatives.
- New BuildRequires: python-setuptools_scm, python-wheel, and (for
  tests) python-lalsimulation.
* Sat Feb 27 2021 Atri Bhattacharya <badshah400@gmail.com>
- Disable python 3.6 builds: no numpy.
* Sun Jan 10 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.2:
  * [gh#gwpy/gwpy#1269]: Fix an issue with file path handling.
  * [gh#gwpy/gwpy#1270]: Fix issues with LIGO_LW column handling.
  * [gh#gwpy/gwpy#1278]: Fix compatibility with matplotlib-3.3.3.
  * [gh#gwpy/gwpy#1279]: Fix compatibility with h5py-3.1.0.
  * [gh#gwpy/gwpy#1281]: Fix issue with error reporting when
    reading LIGO_LW arrays.
- Drop python-gwpy-mp-test.patch: incorporated upstream.
* Mon Nov  2 2020 Atri Bhattacharya <badshah400@gmail.com>
- Add python-gwpy-mp-test.patch: fix an assertion error when
  running test_mp.py [gh#gwpy/gwpy#1273].
* Fri Oct  9 2020 Benjamin Greiner <code@bnavigator.de>
- Fix unit test failures
  * update test section BuildRequires
  * python-gwpy-connectionerror-test.patch
- add examples to %%doc
- update Recommends
* Sun Aug 16 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update list of Requires and BuildRequires changed since version
  2.0.
- Drop Group tag.
* Fri Aug  7 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.1:
  * [gh#gwpy/gwpy#1259] fix compatibility with matplotlib-3.3.0.
* Mon Aug  3 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.0
  * python requirement increased to >=3.6.
  * numpy requirement increased to >=1.12.0.
  * scipy requirement increased to >=1.2.0.
  * astropy requirement increased to >=3.0.0.
  * matplotlib requirement increased to >=3.1.0.
  * [gh#gwpy/gwpy#1247] new GWF I/O API using FrameL.
  * [gh#gwpy/gwpy#1238] new TimeSeries.mask method.
  * [gh#gwpy/gwpy#1139] update to log formatting on plots.
  * [gh#gwpy/gwpy#1207] fix bug writing series to GWF.
  * [gh#gwpy/gwpy#1218] fix API for CIS using requests-ecp.
- Implement %%check section running tests using pytest; add
  necessary BuildRequires for tests to work.
- Add python-gwpy-python3-shell-test.patch: Use python3 when
  testing the python shell.
- Update BuildRequires versions in keeping with upstream
  requirements.
- Drop python2 packages: No longer supported by upstream.
- No longer support i586 (upstream).
* Thu Apr 23 2020 Atri Bhattacharya <badshah400@gmail.com>
- Replace python-bs4 by python-beautifulsoup4 in dependencies.
* Mon Feb  3 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.0.1:
  * No changelog.
* Wed Oct  9 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.15.0
* Thu Jan 31 2019 badshah400@gmail.com
- Enable python2 bindings since we have python2-astropy now.
- Only package gwpy-plot for python3.
* Sun Jan 27 2019 badshah400@gmail.com
- Update to version 0.12.2
- Build only against python3 (python2-astropy not available for
  openSUSE >= 1550).
* Fri Jun 15 2018 badshah400@gmail.com
- Initial package.
